##  Track and Report your progress
SAP LeanIX Reports provides a comprehensive view of your architecture's current state in relation to ESG, which helps you in decision-making, tracking progress, and identifying trends. By generating reports, you can analyze information from various angles and identify areas where improvements can be made.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749fd5b7a44101493d6c5732b2622fe_LowRes.png)
In the above example, the Roadmap report presents data on the energy consumption of different hardware components used by the company, along with their technology lifecycle information. By examining the report, we can pinpoint specific IT components that consume higher energy (highlighted in dark blue) and are nearing the end of their useful life. To gain a better understanding, we can click on each of these components to gather additional contextual information.
Make use of SAP LeanIX custom dashboards to combine multiple visualizations and tell a compelling story. Drive conversations by presenting all relevant ESG information in new dashboards you create with embedded metrics, KPIs, and reports.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274414317a44101496a8c4d3e80eeedf_LowRes.png)
To learn more about creating custom dashboards to track and report, [refer here](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD "Dashboards enable you to consolidate and interpret data in one place, facilitating informed decision-making and promoting efficient task management. Learn how to create, customize, and manage dashboards.").
To summarize, SAP LeanIX reports provide excellent opportunities to address your inquiries and make informed decisions regarding your ESG capabilities. This will enable you to take a significant step toward the Twin Transition.
YesNo
Send
